package it.unibas.acim2pincohibernate.controllo;

import it.unibas.acim2pincohibernate.form.FormInserimentoAutomobile;
import it.unibas.acim2pincohibernate.modello.Automobile;
import it.unibas.acim2pincohibernate.modello.Proprietario;
import it.unibas.acim2pincohibernate.modello.Utente;
import it.unibas.acim2pincohibernate.persistenza.DAOAutomobile;
import it.unibas.acim2pincohibernate.persistenza.DAOException;
import it.unibas.acim2pincohibernate.persistenza.DAOProprietario;
import it.unibas.acim2pincohibernate.persistenza.PersistenceManager;
import it.unibas.pinco.azioni.Azione;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class AzioneInserisciAutomobile implements Azione {
    
    private static Log logger = LogFactory.getLog(AzioneInserisciAutomobile.class);

    private boolean richiestaCorretta(HttpServletRequest request) {
        HttpSession session = request.getSession();
        Utente utente = (Utente)session.getAttribute("utente");
        if (session.isNew() || utente == null || !utente.getRuolo().equals("amministratore")) {
            return false;
        }
        return true;
    }
    
	public String esegui(HttpServletRequest request){
        if (!richiestaCorretta(request)) {
            return "errore";
        }
        HttpSession session = request.getSession(false);
        FormInserimentoAutomobile formAutomobile = new FormInserimentoAutomobile();
        formAutomobile.setTarga(request.getParameter("targa"));
        formAutomobile.setModello(request.getParameter("modello"));
        formAutomobile.setCilindrata(request.getParameter("cilindrata"));
        List errori = formAutomobile.convalida();
        if (errori.size() != 0) {
            request.setAttribute("formAutomobile", formAutomobile);
            request.setAttribute("errori", errori);
            return "erroriConvalida";
        }
        Automobile automobile = new Automobile();
        automobile.setTarga(request.getParameter("targa"));
        automobile.setModello(request.getParameter("modello"));
        automobile.setCilindrata(Integer.parseInt(request.getParameter("cilindrata")));
        try {
            PersistenceManager.beginTransaction();
            Proprietario proprietario = (Proprietario)session.getAttribute("proprietario");
            DAOProprietario.makePersistent(proprietario);
            proprietario.getAutomobili().add(automobile);
            automobile.setProprietario(proprietario);
            DAOAutomobile.makePersistent(automobile);
            PersistenceManager.commitTransaction();
            request.setAttribute("automobile", automobile);
            return "successo";
        } catch (DAOException se) {
            logger.error(se);
            request.setAttribute("messaggioErrore", "Causa dell'errore: " + se.getMessage());
            try {
                PersistenceManager.rollbackTransaction();
            } catch (Exception e) {}
            return "messaggioErrore";
        } finally {
            PersistenceManager.closeSession();
        }
        
    }
}

