package it.unibas.acim2pincohibernate.controllo;

import it.unibas.acim2pincohibernate.form.FormProprietario;
import it.unibas.acim2pincohibernate.modello.Proprietario;
import it.unibas.acim2pincohibernate.modello.Utente;
import it.unibas.acim2pincohibernate.persistenza.DAOException;
import it.unibas.acim2pincohibernate.persistenza.DAOProprietario;
import it.unibas.acim2pincohibernate.persistenza.PersistenceManager;
import it.unibas.pinco.azioni.Azione;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class AzioneInserisciProprietario implements Azione {
    
    private static Log logger = LogFactory.getLog(AzioneInserisciProprietario.class);

    private boolean richiestaCorretta(HttpServletRequest request) {
        HttpSession session = request.getSession();
        Utente utente = (Utente)session.getAttribute("utente");
        if (session.isNew() || utente == null || !utente.getRuolo().equals("amministratore")) {
            return false;
        }
        return true;
    }
    
    public String esegui(HttpServletRequest request){
        if (!richiestaCorretta(request)) {
            return "errore";
        }
        FormProprietario formProprietario = new FormProprietario();
        formProprietario.setNome(request.getParameter("nome"));
        formProprietario.setCodiceFiscale(request.getParameter("codiceFiscale"));
        formProprietario.setCittaDiResidenza(request.getParameter("cittaDiResidenza"));
        formProprietario.setAnnoPatente(request.getParameter("annoPatente"));
        List errori = formProprietario.convalida();
        if (errori.size() != 0) {
            request.setAttribute("formProprietario", formProprietario);
            request.setAttribute("errori", errori);
            return "erroriConvalida";
        }
        Proprietario proprietario = new Proprietario();
        proprietario.setNome(request.getParameter("nome"));
        proprietario.setCodiceFiscale(request.getParameter("codiceFiscale"));
        proprietario.setCittaDiResidenza(request.getParameter("cittaDiResidenza"));
        proprietario.setAnnoPatente(Integer.parseInt(request.getParameter("annoPatente")));
        try {
            PersistenceManager.beginTransaction();
            DAOProprietario.makePersistent(proprietario);
            PersistenceManager.commitTransaction();
            request.setAttribute("proprietario", proprietario);
            return "successo";
        } catch (DAOException se) {
            logger.error(se);
            request.setAttribute("messaggioErrore", "Causa dell'errore: " + se.getMessage());
            try {
                PersistenceManager.rollbackTransaction();
            } catch (Exception e) {}
            return "messaggioErrore";
        } finally {
            PersistenceManager.closeSession();
        }
        
    }
}

