package it.unibas.acim2pincohibernate.form;

import it.unibas.acim2pincohibernate.modello.Proprietario;
import it.unibas.acim2pincohibernate.persistenza.DAOException;
import it.unibas.acim2pincohibernate.persistenza.DAOProprietario;
import it.unibas.acim2pincohibernate.persistenza.PersistenceManager;
import it.unibas.pinco.utilita.Convalidatore;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class FormProprietario {

    private static Log logger = LogFactory.getLog(FormProprietario.class);

    private String codiceFiscale = "";
    private String nome = "";
    private String cittaDiResidenza = "";
    private String annoPatente = "";

    public void setNome(String nome){
        this.nome = nome;
    }

    public void setCodiceFiscale(String codiceFiscale){
        this.codiceFiscale = codiceFiscale;
    }

    public void setCittaDiResidenza(String cittaDiResidenza){
        this.cittaDiResidenza = cittaDiResidenza;
    }

    public void setAnnoPatente(String annoPatente){
        this.annoPatente = annoPatente;
    }

    public String getNome(){
        return nome;
    }

    public String getCodiceFiscale(){
        return codiceFiscale;
    }

    public String getCittaDiResidenza(){
        return cittaDiResidenza;
    }

    public String getAnnoPatente() {
        return annoPatente;
    }

	public List convalida() {
        List errori = new ArrayList();
        Convalidatore.verificaStringaNonNulla(this.codiceFiscale, "codice fiscale", errori);
        Convalidatore.verificaLunghezzaStringa(this.codiceFiscale, 6, "codice fiscale", errori);
        if (errori.size() == 0) {
            try {
                PersistenceManager.getSession();
                Proprietario proprietario = DAOProprietario.findByCodiceFiscale(this.codiceFiscale);
                if (proprietario != null) {
                    errori.add("Errore: codice fiscale gia' esistente nella base di dati");
                }
            } catch (DAOException daoe) {
                logger.error(daoe);
            } finally {
                PersistenceManager.closeSession();
            }
        }
        Convalidatore.verificaStringaNonNulla(this.nome, "nome", errori);
        if (this.nome != null && !this.nome.equals("") && this.nome.indexOf(" ") == -1) {
            errori.add("Errore nel valore del nome: il valore deve contenere nome e cognome");
        }
        Convalidatore.verificaInteroMinimo(this.annoPatente, 1920, "anno patente", errori);  
        return errori;
    }
}