package it.unibas.acim2pincohibernate.persistenza;

import it.unibas.acim2pincohibernate.modello.Proprietario;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Hibernate;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;

public class DAOProprietario {
    
    private static Log logger = LogFactory.getLog(DAOProprietario.class);

    public static Proprietario findByCodiceFiscale(String codiceFiscale) throws DAOException {
        Proprietario proprietario = null;
        try {
            Session session = PersistenceManager.getSession();
            Query query = session.createQuery("from Proprietario where codicefiscale = ?");
            query.setString(0, codiceFiscale);
            List risultato = query.list();
            if (risultato.size() != 0) {
                proprietario = (Proprietario)risultato.get(0);
            }
        } catch (HibernateException e) {
            logger.error(e);
            throw new DAOException(e);
        }
        return proprietario;
    }
    
    public static List findByNome(String nome) throws DAOException {
        List risultato = new ArrayList();
        try {
            Session session = PersistenceManager.getSession();
            Query query = session.createQuery("from Proprietario where nome = ?");
            query.setString(0, nome);
            risultato = query.list();
        } catch (HibernateException e) {
            logger.error(e);
            throw new DAOException(e);
        }
        return risultato;
    }

    public static Collection findAll() throws DAOException {
        Collection risultato;
        try {
            Session session = PersistenceManager.getSession();
            Query query = session.createQuery("from Proprietario");
            risultato = query.list();
            for(Iterator it = risultato.iterator(); it.hasNext(); ) {
                caricaAutomobili((Proprietario)it.next());
            }
        } catch (HibernateException e) {
            logger.error(e);
            throw new DAOException(e);
        }
        return risultato;
    }
    
    public static void caricaAutomobili(Proprietario proprietario) throws DAOException {
        try {
            makePersistent(proprietario);
            Hibernate.initialize(proprietario.getAutomobili());    
        } catch (HibernateException e) {
            logger.error(e);
            throw new DAOException(e);
        }
    }
    
    public static void makePersistent(Proprietario proprietario) throws DAOException {
        try {
            PersistenceManager.getSession().saveOrUpdate(proprietario);
        } catch (HibernateException e) {
            logger.error(e);
            throw new DAOException(e);
        }
    }
    
    public static void makeTransient(Proprietario proprietario) throws DAOException {
        try {
            PersistenceManager.getSession().delete(proprietario);
        } catch (HibernateException e) {
            logger.error(e);
            throw new DAOException(e);
        }
    }
    
}



