package it.unibas.acim2pincohibernate.test.persistenza;

import it.unibas.acim2pincohibernate.modello.Automobile;
import it.unibas.acim2pincohibernate.modello.Proprietario;
import it.unibas.acim2pincohibernate.persistenza.DAOAutomobile;
import it.unibas.acim2pincohibernate.persistenza.DAOProprietario;
import it.unibas.acim2pincohibernate.persistenza.PersistenceManager;
import junit.framework.TestCase;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class TestDAOAutomobile extends TestCase {
    
    private static Log logger = LogFactory.getLog(TestDAOAutomobile.class);
    
    private Automobile automobile;
    private Proprietario proprietario;
    
    protected void setUp() {
        proprietario = new Proprietario();
        proprietario.setCodiceFiscale("cftest1");
        proprietario.setNome("Proprietario di test");
        proprietario.setCittaDiResidenza("citta di test");
        proprietario.setAnnoPatente(2003);
        automobile = new Automobile();
        automobile.setTarga("test1");
        automobile.setModello("Modello di test");
        automobile.setCilindrata(2000);
    }
    
    public void testInserisciAutomobile() {
        Proprietario p = null;
        Automobile a = null;
        try {
            PersistenceManager.beginTransaction();
            automobile.setProprietario(proprietario);
            proprietario.addAutomobile(automobile);
            DAOProprietario.makePersistent(proprietario);
            DAOAutomobile.makePersistent(automobile);
            PersistenceManager.commitTransaction();
            PersistenceManager.closeSession();
            p = DAOProprietario.findByCodiceFiscale("cftest1");
            assertEquals(p.getNome(), "Proprietario di test");
            a = p.getAutomobile(0);
            assertEquals(a.getTarga(), "test1");
        } catch (Exception e) {
            logger.error(e);
            try {
                PersistenceManager.rollbackTransaction();
            } catch (Exception ex) {}
            fail();
        } finally {
            try {
                PersistenceManager.beginTransaction();
                DAOAutomobile.makeTransient(a);
                DAOProprietario.makeTransient(p);
                PersistenceManager.commitTransaction();
                PersistenceManager.closeSession();
            } catch (Exception e) {}
        }
    }
    
}

